# Stores

## `reflow.stores.Store`

::: reflow.stores.Store
    options:
      show_source: true

## `reflow.stores.sqlite.SqliteStore`

::: reflow.stores.sqlite.SqliteStore
    options:
      show_source: true

## `reflow.stores.records.RunRecord`

::: reflow.stores.records.RunRecord
    options:
      show_source: true

## `reflow.stores.records.TaskSpecRecord`

::: reflow.stores.records.TaskSpecRecord
    options:
      show_source: true

## `reflow.stores.records.TaskInstanceRecord`

::: reflow.stores.records.TaskInstanceRecord
    options:
      show_source: true
